@@ -4,7 +4,7 @@
  * control the pace of reading. 
  *****************************************************************************
  * Copyright (C) 1999, 2000 VideoLAN
- * $Id: input_ext-intf.h,v 1.63 2002/03/21 02:27:04 jobi Exp $
+ * $Id: input_ext-intf.h,v 1.66 2002/04/25 02:10:33 jobi Exp $
  *
  * Authors: Christophe Massiot <massiot@via.ecp.fr>
  *
@@ -49,7 +49,7 @@ typedef struct input_bank_s
 
 } input_bank_t;
 
-#ifndef PLUGIN
+#ifndef __PLUGIN__
 extern input_bank_t *p_input_bank;
 #else
 #   define p_input_bank (p_symbols->p_input_bank)
@@ -71,10 +71,8 @@ typedef struct es_descriptor_s
                                            * fast forward and slow motion ?  */
     u8                      i_cat;        /* stream category: video, audio,
                                            * spu, other */
-#ifdef HAVE_SATELLITE
-    int                     i_dmx_fd;     /* used to store demux device
+    int                     i_demux_fd;   /* used to store demux device
                                              file handle */
-#endif
     char                    psz_desc[20]; /* description of ES: audio language
                                            * for instance ; NULL if not
                                            *  available */
@@ -236,8 +234,7 @@ typedef struct stream_descriptor_s
     es_descriptor_t *       p_newly_selected_es;   /* ES selected from
                                                     * the interface */
     es_descriptor_t *       p_removed_es;   /* ES removed from the interface */
-
-
+    
     /* Stream control */
     stream_ctrl_t           control;
 
@@ -331,7 +328,7 @@ typedef struct input_thread_s
 /*****************************************************************************
  * Prototypes
  *****************************************************************************/
-#ifndef PLUGIN
+#ifndef __PLUGIN__
 void   input_InitBank       ( void );
 void   input_EndBank        ( void );
 
