@@ -2,7 +2,7 @@
  * aout_dsp.c : dsp functions library
  *****************************************************************************
  * Copyright (C) 1999-2001 VideoLAN
- * $Id: aout_dsp.c,v 1.26 2002/03/11 07:23:09 gbazin Exp $
+ * $Id: aout_dsp.c,v 1.27.2.2 2002/10/28 23:49:05 jobi Exp $
  *
  * Authors: Michel Kaempf <maxx@via.ecp.fr>
  *          Samuel Hocevar <sam@zoy.org>
@@ -11,7 +11,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -111,7 +111,7 @@ static int aout_Open( aout_thread_t *p_aout )
     }
 
     /* Initialize some variables */
-    if( !(p_aout->p_sys->psz_device = config_GetPszVariable( "dsp_dev" )) )
+    if( !(p_aout->p_sys->psz_device = config_GetPszVariable( "dspdev" )) )
     {
         intf_ErrMsg( "aout error: don't know which audio device to open" );
         free( p_aout->p_sys );
@@ -119,8 +119,8 @@ static int aout_Open( aout_thread_t *p_aout )
     }
 
     /* Open the sound device */
-    if( (p_aout->p_sys->i_fd = open( p_aout->p_sys->psz_device, O_WRONLY ))
-        < 0 )
+    if( (p_aout->p_sys->i_fd = open( p_aout->p_sys->psz_device,
+                    O_WRONLY | O_NDELAY )) < 0 )
     {
         intf_ErrMsg( "aout error: can't open audio device (%s)",
                      p_aout->p_sys->psz_device );
@@ -128,6 +128,8 @@ static int aout_Open( aout_thread_t *p_aout )
         free( p_aout->p_sys );
         return( -1 );
     }
+    fcntl( p_aout->p_sys->i_fd, F_SETFL,
+            fcntl(p_aout->p_sys->i_fd, F_GETFL)&~FNDELAY );
 
     return( 0 );
 }
